The following commit has been merged in the master branch:
commit b8a0dbd784a9e838c3e6735d51bf76a61a63d8e4
Author: Matthias Klose <[email protected]>
Date:   Tue Jun 11 13:49:19 2013 +0200

    dpkg-buildflags: Do not set -fstack-protector on arm64
    
    The flag is not yet supported there.
    
    Closes: #711936
    
    [[email protected]: Update comment. ]
    
    Signed-off-by: Guillem Jover <[email protected]>

diff --git a/debian/changelog b/debian/changelog
index d787320..4b0bcc5 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -90,6 +90,9 @@ dpkg (1.17.0) UNRELEASED; urgency=low
     respect build time setting.
   * Deprecate Dpkg lowercase and exported by default variables, replaced by
     new unified uppercase non-exported by default ones.
+  * Do not set -fstack-protector in the default build flags on arm64 (it's
+    not yet supported). Thanks to Matthias Klose <[email protected]>.
+    Closes: #711936
 
   [ Updated manpages translations ]
   * Fix incorrect translation of "fortify" in French manpage for 
dpkg-buildflags
diff --git a/scripts/Dpkg/Vendor/Debian.pm b/scripts/Dpkg/Vendor/Debian.pm
index 269e1c9..3f30225 100644
--- a/scripts/Dpkg/Vendor/Debian.pm
+++ b/scripts/Dpkg/Vendor/Debian.pm
@@ -122,8 +122,8 @@ sub add_hardening_flags {
        #  (#574716).
        $use_feature{pie} = 0;
     }
-    if ($cpu =~ /^(ia64|alpha|mips|mipsel|hppa)$/ or $arch eq 'arm') {
-       # Stack protector disabled on ia64, alpha, mips, mipsel, hppa.
+    if ($cpu =~ /^(ia64|alpha|mips|mipsel|hppa|arm64)$/ or $arch eq 'arm') {
+       # Stack protector disabled on ia64, alpha, arm64, mips, mipsel, hppa.
        #   "warning: -fstack-protector not supported for this target"
        # Stack protector disabled on arm (ok on armel).
        #   compiler supports it incorrectly (leads to SEGV)

-- 
dpkg's main repository


-- 
To UNSUBSCRIBE, email to [email protected]
with a subject of "unsubscribe". Trouble? Contact [email protected]

Reply via email to